#[non_exhaustive]pub enum LinDist3FlowReferencePolicy {
Auto,
Explicit,
SourcePropagated,
}Expand description
Selection of the fixed phasors used to form LinDist3Flow coefficients.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Auto
Use the instance initial point when present, otherwise propagate source phasors through the no-load line topology.
Explicit
Require the instance to carry a complete voltage initial point.
SourcePropagated
Ignore any initial point and propagate source phasors without line drop.