#[non_exhaustive]pub enum ObjectiveTerm {
NetworkGeneratorCost,
ActivePowerDispatchCost,
}Expand description
One typed objective term.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
NetworkGeneratorCost
The generator cost curves the network states, summed over the in service generators the instance dispatches.
ActivePowerDispatchCost
Active power dispatch costs on the resources represented by a multiconductor calculation record (the BMOPF objective).