#[non_exhaustive]pub struct LinDist3FlowNode {
pub bus: String,
pub terminal: String,
}Expand description
One retained voltage node, identified independently of dense row order.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.bus: Stringterminal: StringTrait Implementations
Sourceimpl Clone for LinDist3FlowNode
impl Clone for LinDist3FlowNode
Sourcefn clone(&self) -> LinDist3FlowNode
fn clone(&self) -> LinDist3FlowNode
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LinDist3FlowNode
impl Debug for LinDist3FlowNode
Sourceimpl<'de> Deserialize<'de> for LinDist3FlowNode
impl<'de> Deserialize<'de> for LinDist3FlowNode
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for LinDist3FlowNode
Sourceimpl JsonSchema for LinDist3FlowNode
impl JsonSchema for LinDist3FlowNode
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Ord for LinDist3FlowNode
impl Ord for LinDist3FlowNode
Sourcefn cmp(&self, other: &LinDist3FlowNode) -> Ordering
fn cmp(&self, other: &LinDist3FlowNode) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for LinDist3FlowNode
impl PartialEq for LinDist3FlowNode
Sourcefn eq(&self, other: &LinDist3FlowNode) -> bool
fn eq(&self, other: &LinDist3FlowNode) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for LinDist3FlowNode
impl PartialOrd for LinDist3FlowNode
Sourceimpl Serialize for LinDist3FlowNode
impl Serialize for LinDist3FlowNode
impl StructuralPartialEq for LinDist3FlowNode