#[non_exhaustive]pub struct LinDist3FlowTopology {
pub nodes: Vec<LinDist3FlowNode>,
pub conductors: Vec<LinDist3FlowOrientedConductor>,
pub roots: Vec<LinDist3FlowNode>,
pub islands: Vec<Vec<LinDist3FlowNode>>,
}Expand description
The source-rooted conductor forest used by the formulation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.nodes: Vec<LinDist3FlowNode>conductors: Vec<LinDist3FlowOrientedConductor>roots: Vec<LinDist3FlowNode>islands: Vec<Vec<LinDist3FlowNode>>Trait Implementations
Sourceimpl Clone for LinDist3FlowTopology
impl Clone for LinDist3FlowTopology
Sourcefn clone(&self) -> LinDist3FlowTopology
fn clone(&self) -> LinDist3FlowTopology
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LinDist3FlowTopology
impl Debug for LinDist3FlowTopology
Sourceimpl<'de> Deserialize<'de> for LinDist3FlowTopology
impl<'de> Deserialize<'de> for LinDist3FlowTopology
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for LinDist3FlowTopology
Sourceimpl JsonSchema for LinDist3FlowTopology
impl JsonSchema for LinDist3FlowTopology
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for LinDist3FlowTopology
impl PartialEq for LinDist3FlowTopology
Sourcefn eq(&self, other: &LinDist3FlowTopology) -> bool
fn eq(&self, other: &LinDist3FlowTopology) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for LinDist3FlowTopology
impl Serialize for LinDist3FlowTopology
impl StructuralPartialEq for LinDist3FlowTopology